==> mingw-w64-libgedit-tepl-6.10.0-2.src.tar.zst: libgedit-tepl-6.10.0/tepl/tepl.h <==
/* SPDX-FileCopyrightText: 2016-2022 - Sébastien Wilmet <swilmet@gnome.org>
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#ifndef TEPL_H
#define TEPL_H

#define TEPL_H_INSIDE

#include <amtk/amtk.h>

#include <tepl/tepl-enum-types.h>

#include <tepl/tepl-abstract-factory.h>
#include <tepl/tepl-application.h>
#include <tepl/tepl-application-window.h>
#include <tepl/tepl-buffer.h>
#include <tepl/tepl-encoding.h>
#include <tepl/tepl-encoding-iconv.h>
#include <tepl/tepl-file.h>
#include <tepl/tepl-file-chooser.h>
#include <tepl/tepl-file-loader.h>
#include <tepl/tepl-file-saver.h>
#include <tepl/tepl-fold-region.h>
#include <tepl/tepl-goto-line-bar.h>
#include <tepl/tepl-gutter-renderer-folds.h>
#include <tepl/tepl-info-bar.h>
#include <tepl/tepl-init.h>
#include <tepl/tepl-io-error-info-bars.h>
#include <tepl/tepl-iter.h>
#include <tepl/tepl-language-chooser.h>
#include <tepl/tepl-language-chooser-dialog.h>
#include <tepl/tepl-language-chooser-widget.h>
#include <tepl/tepl-line-column-indicator.h>
#include <tepl/tepl-menu-shell.h>
#include <tepl/tepl-metadata.h>
#include <tepl/tepl-metadata-manager.h>
#include <tepl/tepl-notebook.h>
#include <tepl/tepl-object-counters.h>
#include <tepl/tepl-overwrite-indicator.h>
#include <tepl/tepl-panel1.h>
#include <tepl/tepl-panel.h>
#include <tepl/tepl-panel-container.h>
#include <tepl/tepl-panel-item.h>
#include <tepl/tepl-panel-switcher-menu.h>
#include <tepl/tepl-panel-switcher-notebook.h>
#include <tepl/tepl-pango.h>
#include <tepl/tepl-prefs.h>
#include <tepl/tepl-prefs-dialog.h>
#include <tepl/tepl-progress-info-bar.h>
#include <tepl/tepl-settings.h>
#include <tepl/tepl-signal-group.h>
#include <tepl/tepl-space-drawer-prefs.h>
#include <tepl/tepl-status-menu-button.h>
#include <tepl/tepl-style-scheme-chooser-widget.h>
#include <tepl/tepl-tab.h>
#include <tepl/tepl-tab-group.h>
#include <tepl/tepl-tab-label.h>
#include <tepl/tepl-tab-loading.h>
#include <tepl/tepl-tab-saving.h>
#include <tepl/tepl-utils.h>
#include <tepl/tepl-view.h>

#undef TEPL_H_INSIDE

#endif /* TEPL_H */

==> mingw-w64-libgedit-tepl-6.12.0-3.src.tar.zst: libgedit-tepl-6.12.0/tepl/tepl.h <==
/* SPDX-FileCopyrightText: 2016-2024 - Sébastien Wilmet
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#ifndef TEPL_H
#define TEPL_H

#define TEPL_H_INSIDE

#include <amtk/amtk.h>

#include <tepl/tepl-enum-types.h>

#include <tepl/tepl-abstract-factory.h>
#include <tepl/tepl-application.h>
#include <tepl/tepl-application-window.h>
#include <tepl/tepl-buffer.h>
#include <tepl/tepl-encoding.h>
#include <tepl/tepl-encoding-iconv.h>
#include <tepl/tepl-file.h>
#include <tepl/tepl-file-chooser.h>
#include <tepl/tepl-file-loader.h>
#include <tepl/tepl-file-saver.h>
#include <tepl/tepl-fold-region.h>
#include <tepl/tepl-goto-line-bar.h>
#include <tepl/tepl-gutter-renderer-folds.h>
#include <tepl/tepl-info-bar.h>
#include <tepl/tepl-init.h>
#include <tepl/tepl-io-error-info-bars.h>
#include <tepl/tepl-iter.h>
#include <tepl/tepl-language-chooser.h>
#include <tepl/tepl-language-chooser-dialog.h>
#include <tepl/tepl-language-chooser-widget.h>
#include <tepl/tepl-line-column-indicator.h>
#include <tepl/tepl-menu-shell.h>
#include <tepl/tepl-metadata.h>
#include <tepl/tepl-metadata-manager.h>
#include <tepl/tepl-notebook.h>
#include <tepl/tepl-object-counters.h>
#include <tepl/tepl-overwrite-indicator.h>
#include <tepl/tepl-panel1.h>
#include <tepl/tepl-panel.h>
#include <tepl/tepl-panel-item.h>
#include <tepl/tepl-panel-notebook.h>
#include <tepl/tepl-panel-simple.h>
#include <tepl/tepl-panel-stack.h>
#include <tepl/tepl-panel-switcher-menu.h>
#include <tepl/tepl-pango.h>
#include <tepl/tepl-prefs.h>
#include <tepl/tepl-prefs-dialog.h>
#include <tepl/tepl-progress-info-bar.h>
#include <tepl/tepl-settings.h>
#include <tepl/tepl-settings-binding-group.h>
#include <tepl/tepl-signal-group.h>
#include <tepl/tepl-space-drawer-prefs.h>
#include <tepl/tepl-status-menu-button.h>
#include <tepl/tepl-style-scheme-chooser-full.h>
#include <tepl/tepl-style-scheme-chooser-simple.h>
#include <tepl/tepl-tab.h>
#include <tepl/tepl-tab-group.h>
#include <tepl/tepl-tab-label.h>
#include <tepl/tepl-tab-loading.h>
#include <tepl/tepl-tab-saving.h>
#include <tepl/tepl-utils.h>
#include <tepl/tepl-view.h>
#include <tepl/tepl-window-state.h>

#undef TEPL_H_INSIDE

#endif /* TEPL_H */
